@@ -3,15 +3,9 @@ package Jifty::DBI::Filter::DateTime;
 use warnings;
 use strict;
 
-use base qw|Jifty::DBI::Filter|;
-use DateTime                  ();
-use DateTime::Format::ISO8601 ();
+use base qw(Jifty::DBI::Filter);
+use DateTime                   ();
 use DateTime::Format::Strptime ();
-use Carp ();
-
-use constant _time_zone => '';
-use constant _strptime  => '%Y-%m-%d %H:%M:%S';
-
 
 =head1 NAME
 
@@ -20,14 +14,13 @@ Jifty::DBI::Filter::DateTime - DateTime object wrapper around date columns
 =head1 DESCRIPTION
 
 This filter allow you to work with DateTime objects instead of
-plain text dates.  If the column type is "date", then the hour,
-minute, and second information is discarded when encoding.
+plain text dates.
 
 =head2 encode
 
 If value is DateTime object then converts it into ISO format
-C<YYYY-MM-DD hh:mm:ss>. Does nothing if value is not defined or
-string.
+C<YYYY-MM-DD hh:mm:ss>. Does nothing if value is not defined
+or string.
 
 =cut
 
@@ -39,18 +32,15 @@ sub encode {
 
     return unless UNIVERSAL::isa( $$value_ref, 'DateTime' );
 
-    if (my $tz = $self->_time_zone) {
-	$$value_ref = $$value_ref->clone;
-	$$value_ref->time_zone('floating');
-    }
-    $$value_ref = $$value_ref->strftime($self->_strptime);
+    $$value_ref = $$value_ref->strftime("%Y-%m-%d %H:%M:%S");
+
     return 1;
 }
 
 =head2 decode
 
-If value is defined then converts it into DateTime object otherwise do
-nothing.
+If value is defined then converts it into DateTime object otherwise
+do nothing.
 
 =cut
 
@@ -66,23 +56,13 @@ sub decode {
 #    server time_zone, by default ISO
 # other DBs may have own formats(Interbase for example can be forced to use special format)
 # but we need Jifty::DBI::Handle here to get DB type
-
-    my $str = join('T', split ' ', $$value_ref, 2);
-    my $dt;
-    eval { $dt  = DateTime::Format::ISO8601->parse_datetime($str) };
-
-    if ($@) { # if datetime can't decode this, scream loudly with a useful error message
-        Carp::cluck($@);
-        return;
-    }
-
+    my $parser
+        = DateTime::Format::Strptime->new( pattern => '%Y-%m-%d %H:%M:%S', );
+    my $dt = $parser->parse_datetime($$value_ref);
     if ($dt) {
-	my $tz = $self->_time_zone;
-	$dt->time_zone($tz) if $tz;
-
-        $dt->set_formatter(DateTime::Format::Strptime->new(pattern => $self->_strptime));
         $$value_ref = $dt;
-    } else {
+    }
+    else {
         return;
     }
 }
