@@ -51,11 +51,11 @@ preloaded with error info
 
 sub insert {
     my $self  = shift;
-    my $table = shift;
+     my $table = shift;
     my %args  = (@_);
     my $sth   = $self->SUPER::insert( $table, %args );
 
-    unless ($sth) {
+     unless ($sth) {
         return ($sth);
     }
 
@@ -71,9 +71,10 @@ sub insert {
     $seqsth->execute;
     $self->{'id'} = $seqsth->fetchrow_array();
 
-    return ( $self->{'id'} );
+   return ( $self->{'id'} );
 }
 
+
 =head2 id_sequence_name TABLE
 
 Takes a TABLE name and returns the name of the  sequence of the primary key for that table.
@@ -84,9 +85,7 @@ sub id_sequence_name {
     my $self  = shift;
     my $table = shift;
 
-    return $self->{'_sequences'}{$table}
-        if ( exists $self->{'_sequences'}{$table} );
-
+    return $self->{'_sequences'}{$table} if (exists $self->{'_sequences'}{$table});
     #Lets get the id of that row we just inserted
     my $seq;
     my $colinfosth = $self->dbh->column_info( undef, undef, lc($table), '%' );
@@ -95,38 +94,33 @@ sub id_sequence_name {
         # Regexp from DBIx::Class's Pg handle. Thanks to Marcus Ramberg
         if ( defined $foo->{'COLUMN_DEF'}
             && $foo->{'COLUMN_DEF'}
-            =~ m!^nextval\(+'"?([^"']+)"?'(::(?:text|regclass)\))+!i )
+            =~ m!^nextval\('"?([^"']+)"?'::(?:text|regclass)\)!i )
         {
             return $self->{'_sequences'}{$table} = $1;
         }
 
     }
-    my $ret = Class::ReturnValue->new();
-    $ret->as_error(
-        errno        => '-1',
-        message      => "Found no sequence for $table",
-        do_backtrace => undef
-    );
-    return ( $ret->return_value );
+            my $ret = Class::ReturnValue->new();
+           $ret->as_error(
+                errno   => '-1',
+                message => "Found no sequence for $table",
+                do_backtrace => undef
+            );
+           return ( $ret->return_value );
+ 
+ }
+ 
+ 
+=head2 binary_safe_blobs
 
-}
-
-=head2 blob_params column_NAME column_type
-
-Returns a hash ref for the bind_param call to identify BLOB types used
-by the current database for a particular column type.  The current
-Postgres implementation only supports BYTEA types.
+Return undef, as no current version of postgres supports binary-safe
+blobs
 
 =cut
 
-sub blob_params {
-    my $self   = shift;
-    my $name = shift;
-    my $type = shift;
-
-    # Don't assign to key 'value' as it is defined later.
-    return ( { pg_type => DBD::Pg::PG_BYTEA() } ) if $type eq "blob";
-    return ( {} );
+sub binary_safe_blobs {
+    my $self = shift;
+    return (undef);
 }
 
 =head2 apply_limits STATEMENTREF ROWS_PER_PAGE FIRST_ROW
@@ -167,17 +161,26 @@ Returns a column operator value triple.
 
 sub _make_clause_case_insensitive {
     my $self     = shift;
-    my $column   = shift;
+    my $column    = shift;
     my $operator = shift;
     my $value    = shift;
 
-    if ($self->_case_insensitivity_valid($column, $operator, $value)) {
-        if ( $operator =~ /(?:LIKE|=)/i ) {
-            $column = "LOWER($column)";
-            $value = "LOWER($value)";
-        }
+    if ( $value =~ /^['"]?\d+['"]?$/ )
+    {    # we don't need to downcase numeric values
+        return ( $column, $operator, $value );
+    }
+
+    if ( $operator =~ /LIKE/i ) {
+        $operator =~ s/LIKE/ILIKE/ig;
+        return ( $column, $operator, $value );
+    }
+    elsif ( $operator =~ /=/ ) {
+        return ( "LOWER($column)", $operator, $value, "LOWER(?)" );
+    }
+    else {
+        $self->SUPER::_make_clause_case_insensitive( $column, $operator,
+            $value );
     }
-    return ( $column, $operator, $value );
 }
 
 =head2 distinct_query STATEMENTREF
@@ -187,44 +190,24 @@ takes an incomplete SQL SELECT statement and massages it to return a DISTINCT re
 =cut
 
 sub distinct_query {
-  my $self         = shift;
-  my $statementref = shift;
-  my $sb           = shift;
-  my $table        = $sb->table;
+    my $self = shift;
+    my $statementref = shift;
+    my $sb = shift;
+    my $table = $sb->table;
 
-  if (
-    grep {
-      ( defined $_->{'alias'} and $_->{'alias'} ne 'main' )
-        || defined $_->{'function'}
-    } @{ $sb->order_by }
-    )
-  {
-
-    # If we are ordering by something not in 'main', we need to GROUP
-    # BY and adjust the ORDER_BY accordingly
-    local $sb->{group_by}
-      = [ @{ $sb->{group_by} || [] }, { column => 'id' } ];
-    local $sb->{order_by} = [
-      map {
-          my $alias = $_->{alias} || '';
-          my $column = $_->{column};
-          $alias .= '.' if $alias;
-          #warn "alias $alias => column $column\n";
-            ((!$alias or $alias eq 'main.') and $column eq 'id')
-          ? $_
-          : { %{$_}, alias => '', column => "min($alias$column)" }
-        } @{ $sb->{order_by} }
-    ];
-    my $group = $sb->_group_clause;
-    my $order = $sb->_order_clause;
-    $$statementref
-      = "SELECT ".$sb->_preload_columns." FROM ( SELECT main.id FROM $$statementref $group $order ) distinctquery, $table main WHERE (main.id = distinctquery.id)";
-  }
-  else {
-    $$statementref = "SELECT DISTINCT ".$sb->_preload_columns." FROM $$statementref";
-    $$statementref .= $sb->_group_clause;
-    $$statementref .= $sb->_order_clause;
-  }
+    if ($sb->_order_clause =~ /(?<!main)\./) {
+        # If we are ordering by something not in 'main', we need to GROUP
+        # BY and adjust the ORDER_BY accordingly
+        local $sb->{group_by} = [@{$sb->{group_by} || []}, {column => 'id'}];
+        local $sb->{order_by} = [map {($_->{alias} and $_->{alias} ne "main") ? {%{$_}, column => "min(".$_->{column}.")"}: $_} @{$sb->{order_by}}];
+        my $group = $sb->_group_clause;
+        my $order = $sb->_order_clause;
+        $$statementref = "SELECT main.* FROM ( SELECT main.id FROM $$statementref $group $order ) distinctquery, $table main WHERE (main.id = distinctquery.id)";
+    } else {
+        $$statementref = "SELECT DISTINCT main.* FROM $$statementref";
+       $$statementref .= $sb->_group_clause;
+        $$statementref .= $sb->_order_clause;
+    }
 }
 
 1;
